==> haskell-tasty-inspection-testing-0.2-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-inspection-testing
version:              0.2
visibility:           public
id:                   tasty-inspection-testing-0.2-2ui8PZNOhCW9Cr9gmPtBMc
key:                  tasty-inspection-testing-0.2-2ui8PZNOhCW9Cr9gmPtBMc
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  b04a98d9a66d5d9ba77728e4a68d1ecb
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-inspection-testing-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-inspection-testing-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2-2ui8PZNOhCW9Cr9gmPtBMc
depends:
    base-4.15.1.0 ghc-9.0.2
    inspection-testing-0.5-E1OaW6tRISQ8DDKCsoVgbM
    tasty-1.4.2.3-LfCoZZg5ttU5VpHV083ruq template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-inspection-testing-0.2-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tasty-inspection-testing.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tasty-inspection-testing
version:              0.2
visibility:           public
id:                   tasty-inspection-testing-0.2-2pGE0SXIzTJFL8Iem9qtxe
key:                  tasty-inspection-testing-0.2-2pGE0SXIzTJFL8Iem9qtxe
license:              MIT
copyright:            2017 Joachim Breitner, 2021 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Joachim Breitner, Andrew Lelechenko
homepage:             https://github.com/Bodigrim/tasty-inspection-testing
synopsis:             Inspection testing support for tasty
description:          Integrate @inspection-testing@ into @tasty@ test suites.
category:             Testing
abi:                  d1a4f1ba2b203cb3e0ad771bf4f0cf34
exposed:              True
exposed-modules:      Test.Tasty.Inspection Test.Tasty.Inspection.Plugin
hidden-modules:       Test.Tasty.Inspection.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tasty-inspection-testing-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tasty-inspection-testing-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-inspection-testing
hs-libraries:         HStasty-inspection-testing-0.2-2pGE0SXIzTJFL8Iem9qtxe
depends:
    base-4.15.1.0 ghc-9.0.2
    inspection-testing-0.5-E1OaW6tRISQ8DDKCsoVgbM
    tasty-1.4.2.3-GZeL6u6d7NUB6KDbi0bUp3 template-haskell-2.17.0.0

haddock-interfaces:
    /usr/share/doc/haskell-tasty-inspection-testing/html/tasty-inspection-testing.haddock

haddock-html:         /usr/share/doc/haskell-tasty-inspection-testing/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
